@@ -19,15 +19,13 @@
 
 DELIMITER /
 
--- give PeopleFlows friendlier names
 
-update krms_typ_t set nm='Notify PeopleFlow' where typ_id = '1000'
-/
-update krms_typ_t set nm='Route to PeopleFlow' where typ_id = '1001'
-/
+--
+-- KULRICE-10175: implementation for allowing application modules to send notifications with custom doc types
+--
+-- Adding optional document type name field
+--
 
--- remove constraint that is preventing compound props from persisting
-
-alter table krms_cmpnd_prop_props_t modify seq_no decimal(5,0) default null
+ALTER TABLE KREN_NTFCTN_T ADD COLUMN DOC_TYP_NM VARCHAR(64)
 /
 DELIMITER ;
